# Include the BeakerLib environment
. /usr/share/beakerlib/beakerlib.sh

# Set the full test name
TEST="testA"

# Package being tested
PACKAGE="openldap"

# Required packages.
PACKAGES=( "openldap"         \
           "openldap-clients" \
           "openldap-servers" \
           "rsyslog"          )

rlJournalStart

  rlPhaseStartSetup

    # Backup service. 
    rlServiceStop "slapd"
    rlServiceStop "rsyslog"

    # Check & install reqiured packages.
    yum clean all
    for P in ${PACKAGES[@]}; do
        rlCheckRpm $P || rlRun "yum -y install $P" 0 "Installing $P"
    done

    # Backup configuration and database.
    rlFileBackup "/etc/hosts"
    rlFileBackup "/etc/nsswitch.conf"
    rlFileBackup "/etc/nslcd.conf"
    rlFileBackup "/etc/rsyslog.conf"
    rlFileBackup "/etc/openldap/slapd.conf"
    rlFileBackup "/etc/openldap/ldap.conf"
    rlFileBackup "/etc/sysconfig/ldap"
    rlFileBackup "/etc/openldap/cacerts/" && rlRun "rm -rf /etc/openldap/cacerts/*" 0
    rlFileBackup "/etc/openldap/slapd.d/" && rlRun "rm -rf /etc/openldap/slapd.d/*" 0
    rlFileBackup "/var/run/openldap/" && rlRun "rm -rf /var/run/openldap/*" 0
    rlFileBackup "/var/lib/ldap/" && rlRun "rm -rf /var/lib/ldap/*" 0
    
    # Enable logging.
    rlRun "echo 'local4.* /var/log/slapd.log' >> /etc/rsyslog.conf" 0
    rlRun "service rsyslog start && sleep 5"

    # Configure.
    rlRun "echo '127.0.0.1 my-domain.com' >> /etc/hosts" 0
    rlRun "cp -f nsswitch.conf /etc/nsswitch.conf" 0
    rlRun "cp -f nslcd.conf /etc/nslcd.conf" 0
    rlRun "cp -f slapd.conf /etc/openldap/slapd.conf" 0
    rlRun "cp -f ldap.conf /etc/openldap/ldap.conf" 0
    rlRun "cp -f ldap /etc/sysconfig/ldap" 0
    rlRun "cp -f *.pem /etc/openldap/cacerts/" 0
    rlRun "chown ldap:ldap /etc/openldap/cacerts/*" 0
    rlRun "chmod 400 /etc/openldap/cacerts/*" 0
    rlRun "slaptest -f /etc/openldap/slapd.conf -F /etc/openldap/slapd.d/" 0-255
    rlRun "chown -R ldap:ldap /etc/openldap/slapd.d/" 0
    rlRun "cacertdir_rehash /etc/openldap/cacerts/" 0

    # Load testing data.
    rlRun "slapadd -l data.ldif" 0
    rlRun "chown -R ldap:ldap /var/lib/ldap" 0

    # SELinux cleaning.
    rlRun "restorecon -Rv /etc/"
    
    # Start.
    rlRun "service slapd start && sleep 5" 0

  rlPhaseEnd

  rlPhaseStartTest  

    # Testing.

    # No SSL/TLS.
    rlRun "ldapsearch -H ldap://my-domain.com -x '*'" 0 "No SSL/TLS"

    # TLS.
    rlRun "ldapsearch -H ldap://my-domain.com -x -ZZ '*'" 0 "TLS"
 
    # SSL.
    rlRun "ldapsearch -H ldaps://my-domain.com -x '*'" 0 "SSL"

    # nss-pam-ldapd
    rlRun "getent passwd ldapuser" 0

    #PS1="[debug] " bash

  rlPhaseEnd

  rlPhaseStartCleanup
  
    # Stop.
    rlRun "service slapd stop && sleep 5" 0
    
    # Restore configuration backup.
    rlFileRestore
   
    # Restore service backup.
    rlServiceRestore "slapd"
    rlServiceRestore "rsyslog"

  rlPhaseEnd

rlJournalEnd

# Print the test report
rlJournalPrintText
